GoogleNativeAd class

Constructors

GoogleNativeAd(String adUnitId, String factoryId, void listener(GoogleNativeAdEvent, dynamic)?)

Properties

adId String
final
adUnitId String
final
factoryId String
final
hashCode int
The hash code for this object.
no setterinherited
listener → void Function(GoogleNativeAdEvent, dynamic)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() Future<void>
load() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

CHANNEL_ID → const String